<template>
  <div class="scroll-pagination"  ref="content" @scroll="scrollFn">
    <slot></slot>
    <el-button
        v-if="isLoding"
        type="text"
        style="display: flex; margin: 0 auto; color: #909399"
        ><i class="el-icon-loading" style="font-size:20px"></i
      ></el-button>
    <el-button
      type="text"
      v-if="finishLoding"
      style="display: flex; margin: 0 auto; color: #909399"
      >已经没有更多啦~</el-button
    >
  </div>
</template>

<script>
export default {
  name: 'ScrollPagination',
  props: {
    finishLoding: {
      type:Boolean,
      default:false
    }
  },
  data() {
    return {
      isLoding: false,
    }
  },
  mounted(){
    window.addEventListener("scroll", this.throttle(this.scrollFn, 20000));
  },
  methods: {
    scrollFn() {
      let content = this.$refs.content
      if (content.scrollTop + content.clientHeight >= content.scrollHeight) {
        if(!this.finishLoding){
          this.loadMore()
        }else{
          this.isLoding = false
        }
      }
    },
    loadMore(){
      if (this.isLoding) return
      this.isLoding = true
      // Simulate loading data (replace with your own API call)
      setTimeout(() => {
        this.$emit('load')
        this.isLoding = false
      }, 1000)
    },
    throttle(fn, wait) {
      // 封装函数进行节流
      var timer = null;
      return function () {
        var context = this;
        var args = arguments;
        if (!timer) {
          timer = setTimeout(function () {
            fn.apply(context, args);
            timer = null;
          }, wait);
        }
      };
    },
  },
  destroyed() {
    window.removeEventListener("scroll", this.throttle(), false);
  },
}
</script>

<style scoped>
.scroll-pagination {
  height: 100%;
  overflow-y: auto;
}
</style>
